Exception: RubyFsStack::ServerError
- Inherits:
-
FamilySearchError
- Object
- StandardError
- FamilySearchError
- RubyFsStack::ServerError
- Defined in:
- lib/ruby-fs-stack/errors.rb
Overview
500 Server Error. A generic server error or multiple server errors occurred. If you get this error, please report it at https://issues.devnet.familysearch.org.
Instance Attribute Summary
Attributes inherited from FamilySearchError
Method Summary
Methods inherited from FamilySearchError
Constructor Details
This class inherits a constructor from RubyFsStack::FamilySearchError